Extensions
=============

This page will list packages which have been developed as extensions to pyrolite.

.. note:: This page is a work in progress and will updated soon as submodules from
    :mod:`pyrolite.ext` are migrated out of pyrolite to reduce installation overheads
    and unnecessary dependencies.

`pyrolite-meltsutil <https://pyrolite-meltsutil.readthedocs.io>`__
-------------------------------------------------------------------

* :mod:`pyrolite` extension which wraps the :code:`alphaMELTS` executable
* Functions for working with :code:`alphaMELTS` tables
* Eventually, this will likely instead link to *under-development* python-MELTS.

.. note:: There are some great things happening on the MELTS-for-scripting front;
          these utilities will be intended to link your data to these tools.
